/****************************************************************************
** Meta object code from reading C++ file 'permissionstoreinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "permissionstoreinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'permissionstoreinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN48OrgFreedesktopImplPortalPermissionStoreInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopImplPortalPermissionStoreInterface::qt_create_metaobjectdata<qt_meta_tag_ZN48OrgFreedesktopImplPortalPermissionStoreInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopImplPortalPermissionStoreInterface",
        "Changed",
        "",
        "table",
        "id",
        "deleted",
        "QDBusVariant",
        "data",
        "QMap<QString,QStringList>",
        "permissions",
        "Delete",
        "QDBusPendingReply<>",
        "DeletePermission",
        "app",
        "GetPermission",
        "QDBusPendingReply<QStringList>",
        "List",
        "Lookup",
        "QDBusPendingReply<QMap<QString,QStringList>,QDBusVariant>",
        "QDBusReply<QMap<QString,QStringList>>",
        "QDBusVariant&",
        "Set",
        "create",
        "app_permissions",
        "SetPermission",
        "SetValue",
        "version"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Changed'
        QtMocHelpers::SignalData<void(const QString &, const QString &, bool, const QDBusVariant &, const QMap<QString,QStringList> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::Bool, 5 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'Delete'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(10, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'DeletePermission'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QString &)>(12, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'GetPermission'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(const QString &, const QString &, const QString &)>(14, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'List'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(const QString &)>(16, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'Lookup'
        QtMocHelpers::SlotData<QDBusPendingReply<QMap<QString,QStringList>,QDBusVariant>(const QString &, const QString &)>(17, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'Lookup'
        QtMocHelpers::SlotData<QDBusReply<QMap<QString,QStringList> >(const QString &, const QString &, QDBusVariant &)>(17, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { 0x80000000 | 20, 7 },
        }}),
        // Slot 'Set'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, bool, const QString &, const QMap<QString,QStringList> &, const QDBusVariant &)>(21, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 22 }, { QMetaType::QString, 4 }, { 0x80000000 | 8, 23 },
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'SetPermission'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, bool, const QString &, const QString &, const QStringList &)>(24, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 22 }, { QMetaType::QString, 4 }, { QMetaType::QString, 13 },
            { QMetaType::QStringList, 9 },
        }}),
        // Slot 'SetValue'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, bool, const QString &, const QDBusVariant &)>(25, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 22 }, { QMetaType::QString, 4 }, { 0x80000000 | 6, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'version'
        QtMocHelpers::PropertyData<uint>(26, QMetaType::UInt, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopImplPortalPermissionStoreInterface, qt_meta_tag_ZN48OrgFreedesktopImplPortalPermissionStoreInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopImplPortalPermissionStoreInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN48OrgFreedesktopImplPortalPermissionStoreInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN48OrgFreedesktopImplPortalPermissionStoreInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN48OrgFreedesktopImplPortalPermissionStoreInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopImplPortalPermissionStoreInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopImplPortalPermissionStoreInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Changed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QMap<QString,QStringList>>>(_a[5]))); break;
        case 1: { QDBusPendingReply<> _r = _t->Delete((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->DeletePermission((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<QStringList> _r = _t->GetPermission((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<QStringList> _r = _t->List((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<QMap<QString,QStringList>,QDBusVariant> _r = _t->Lookup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QMap<QString,QStringList>,QDBusVariant>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusReply<QMap<QString,QStringList>> _r = _t->Lookup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant&>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusReply<QMap<QString,QStringList>>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->Set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QMap<QString,QStringList>>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->SetPermission((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->SetValue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopImplPortalPermissionStoreInterface::*)(const QString & , const QString & , bool , const QDBusVariant & , const QMap<QString,QStringList> & )>(_a, &OrgFreedesktopImplPortalPermissionStoreInterface::Changed, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->version(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopImplPortalPermissionStoreInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopImplPortalPermissionStoreInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN48OrgFreedesktopImplPortalPermissionStoreInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopImplPortalPermissionStoreInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void OrgFreedesktopImplPortalPermissionStoreInterface::Changed(const QString & _t1, const QString & _t2, bool _t3, const QDBusVariant & _t4, const QMap<QString,QStringList> & _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4, _t5);
}
QT_WARNING_POP
