/****************************************************************************
** Meta object code from reading C++ file 'flatpakpermission.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../flatpak-kcm-6.7.3/flatpakpermission.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'flatpakpermission.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN29FlatpakPermissionsSectionTypeE_t {};
} // unnamed namespace

template <> constexpr inline auto FlatpakPermissionsSectionType::qt_create_metaobjectdata<qt_meta_tag_ZN29FlatpakPermissionsSectionTypeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FlatpakPermissionsSectionType",
        "Type",
        "Basic",
        "Filesystems",
        "Advanced",
        "SubsystemsShared",
        "Sockets",
        "Devices",
        "Features",
        "SessionBus",
        "SystemBus",
        "Environment"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(1, 1, QMC::EnumFlags{}).add({
            {    2, Type::Basic },
            {    3, Type::Filesystems },
            {    4, Type::Advanced },
            {    5, Type::SubsystemsShared },
            {    6, Type::Sockets },
            {    7, Type::Devices },
            {    8, Type::Features },
            {    9, Type::SessionBus },
            {   10, Type::SystemBus },
            {   11, Type::Environment },
        }),
    };
    return QtMocHelpers::metaObjectData<FlatpakPermissionsSectionType, qt_meta_tag_ZN29FlatpakPermissionsSectionTypeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FlatpakPermissionsSectionType::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29FlatpakPermissionsSectionTypeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29FlatpakPermissionsSectionTypeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29FlatpakPermissionsSectionTypeE_t>.metaTypes,
    nullptr
} };

void FlatpakPermissionsSectionType::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FlatpakPermissionsSectionType *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *FlatpakPermissionsSectionType::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FlatpakPermissionsSectionType::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29FlatpakPermissionsSectionTypeE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int FlatpakPermissionsSectionType::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN18FlatpakSimpleEntryE_t {};
} // unnamed namespace

template <> constexpr inline auto FlatpakSimpleEntry::qt_create_metaobjectdata<qt_meta_tag_ZN18FlatpakSimpleEntryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FlatpakSimpleEntry"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FlatpakSimpleEntry, qt_meta_tag_ZN18FlatpakSimpleEntryE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FlatpakSimpleEntry::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18FlatpakSimpleEntryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18FlatpakSimpleEntryE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18FlatpakSimpleEntryE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN23FlatpakFilesystemsEntryE_t {};
} // unnamed namespace

template <> constexpr inline auto FlatpakFilesystemsEntry::qt_create_metaobjectdata<qt_meta_tag_ZN23FlatpakFilesystemsEntryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FlatpakFilesystemsEntry",
        "AccessMode",
        "ReadOnly",
        "ReadWrite",
        "Create",
        "Deny"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'AccessMode'
        QtMocHelpers::EnumData<enum AccessMode>(1, 1, QMC::EnumIsScoped).add({
            {    2, AccessMode::ReadOnly },
            {    3, AccessMode::ReadWrite },
            {    4, AccessMode::Create },
            {    5, AccessMode::Deny },
        }),
    };
    return QtMocHelpers::metaObjectData<FlatpakFilesystemsEntry, qt_meta_tag_ZN23FlatpakFilesystemsEntryE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FlatpakFilesystemsEntry::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23FlatpakFilesystemsEntryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23FlatpakFilesystemsEntryE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23FlatpakFilesystemsEntryE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN18PolicyChoicesModelE_t {};
} // unnamed namespace

template <> constexpr inline auto PolicyChoicesModel::qt_create_metaobjectdata<qt_meta_tag_ZN18PolicyChoicesModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PolicyChoicesModel"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PolicyChoicesModel, qt_meta_tag_ZN18PolicyChoicesModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PolicyChoicesModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PolicyChoicesModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PolicyChoicesModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18PolicyChoicesModelE_t>.metaTypes,
    nullptr
} };

void PolicyChoicesModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PolicyChoicesModel *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *PolicyChoicesModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PolicyChoicesModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PolicyChoicesModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int PolicyChoicesModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN22FilesystemChoicesModelE_t {};
} // unnamed namespace

template <> constexpr inline auto FilesystemChoicesModel::qt_create_metaobjectdata<qt_meta_tag_ZN22FilesystemChoicesModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FilesystemChoicesModel"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FilesystemChoicesModel, qt_meta_tag_ZN22FilesystemChoicesModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FilesystemChoicesModel::staticMetaObject = { {
    QMetaObject::SuperData::link<PolicyChoicesModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22FilesystemChoicesModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22FilesystemChoicesModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22FilesystemChoicesModelE_t>.metaTypes,
    nullptr
} };

void FilesystemChoicesModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FilesystemChoicesModel *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *FilesystemChoicesModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FilesystemChoicesModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22FilesystemChoicesModelE_t>.strings))
        return static_cast<void*>(this);
    return PolicyChoicesModel::qt_metacast(_clname);
}

int FilesystemChoicesModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PolicyChoicesModel::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN22DBusPolicyChoicesModelE_t {};
} // unnamed namespace

template <> constexpr inline auto DBusPolicyChoicesModel::qt_create_metaobjectdata<qt_meta_tag_ZN22DBusPolicyChoicesModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DBusPolicyChoicesModel"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DBusPolicyChoicesModel, qt_meta_tag_ZN22DBusPolicyChoicesModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DBusPolicyChoicesModel::staticMetaObject = { {
    QMetaObject::SuperData::link<PolicyChoicesModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22DBusPolicyChoicesModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22DBusPolicyChoicesModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22DBusPolicyChoicesModelE_t>.metaTypes,
    nullptr
} };

void DBusPolicyChoicesModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusPolicyChoicesModel *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *DBusPolicyChoicesModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusPolicyChoicesModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22DBusPolicyChoicesModelE_t>.strings))
        return static_cast<void*>(this);
    return PolicyChoicesModel::qt_metacast(_clname);
}

int DBusPolicyChoicesModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PolicyChoicesModel::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN22FlatpakPermissionModelE_t {};
} // unnamed namespace

template <> constexpr inline auto FlatpakPermissionModel::qt_create_metaobjectdata<qt_meta_tag_ZN22FlatpakPermissionModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FlatpakPermissionModel",
        "referenceChanged",
        "",
        "showAdvancedChanged",
        "settingsChanged",
        "togglePermissionAtRow",
        "row",
        "setPermissionValueAtRow",
        "QVariant",
        "newValue",
        "addUserEnteredPermission",
        "rawSection",
        "name",
        "value",
        "valuesModelForSectionType",
        "PolicyChoicesModel*",
        "valuesModelForFilesystemsSection",
        "valuesModelForBusSections",
        "sectionHeaderForSectionType",
        "sectionAddButtonToolTipTextForSectionType",
        "permissionExists",
        "isFilesystemNameValid",
        "isDBusServiceNameValid",
        "isEnvironmentVariableNameValid",
        "reference",
        "FlatpakReference*",
        "showAdvanced",
        "isDefaults",
        "isSaveNeeded",
        "Roles",
        "Name",
        "Section",
        "Description",
        "IsNotDummy",
        "CanBeDisabled",
        "IsDefaultEnabled",
        "IsEffectiveEnabled",
        "DefaultValue",
        "EffectiveValue",
        "ValuesModel"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'referenceChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showAdvancedChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'settingsChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'togglePermissionAtRow'
        QtMocHelpers::SlotData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'setPermissionValueAtRow'
        QtMocHelpers::SlotData<void(int, const QVariant &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'addUserEnteredPermission'
        QtMocHelpers::SlotData<void(int, const QString &, const QVariant &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { QMetaType::QString, 12 }, { 0x80000000 | 8, 13 },
        }}),
        // Method 'valuesModelForSectionType'
        QtMocHelpers::MethodData<PolicyChoicesModel *(int)>(14, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::Int, 11 },
        }}),
        // Method 'valuesModelForFilesystemsSection'
        QtMocHelpers::MethodData<PolicyChoicesModel *()>(16, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Method 'valuesModelForBusSections'
        QtMocHelpers::MethodData<PolicyChoicesModel *()>(17, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Method 'sectionHeaderForSectionType'
        QtMocHelpers::MethodData<QString(int)>(18, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 11 },
        }}),
        // Method 'sectionAddButtonToolTipTextForSectionType'
        QtMocHelpers::MethodData<QString(int)>(19, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 11 },
        }}),
        // Method 'permissionExists'
        QtMocHelpers::MethodData<bool(int, const QString &) const>(20, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 11 }, { QMetaType::QString, 12 },
        }}),
        // Method 'isFilesystemNameValid'
        QtMocHelpers::MethodData<bool(const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 12 },
        }}),
        // Method 'isDBusServiceNameValid'
        QtMocHelpers::MethodData<bool(const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 12 },
        }}),
        // Method 'isEnvironmentVariableNameValid'
        QtMocHelpers::MethodData<bool(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'reference'
        QtMocHelpers::PropertyData<FlatpakReference*>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'showAdvanced'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isDefaults'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'isSaveNeeded'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(29, 29, QMC::EnumFlags{}).add({
            {   30, Roles::Name },
            {   31, Roles::Section },
            {   32, Roles::Description },
            {   33, Roles::IsNotDummy },
            {   34, Roles::CanBeDisabled },
            {   35, Roles::IsDefaultEnabled },
            {   36, Roles::IsEffectiveEnabled },
            {   37, Roles::DefaultValue },
            {   38, Roles::EffectiveValue },
            {   39, Roles::ValuesModel },
        }),
    };
    return QtMocHelpers::metaObjectData<FlatpakPermissionModel, qt_meta_tag_ZN22FlatpakPermissionModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FlatpakPermissionModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22FlatpakPermissionModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22FlatpakPermissionModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22FlatpakPermissionModelE_t>.metaTypes,
    nullptr
} };

void FlatpakPermissionModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FlatpakPermissionModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->referenceChanged(); break;
        case 1: _t->showAdvancedChanged(); break;
        case 2: _t->settingsChanged(); break;
        case 3: _t->togglePermissionAtRow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->setPermissionValueAtRow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 5: _t->addUserEnteredPermission((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 6: { PolicyChoicesModel* _r = _t->valuesModelForSectionType((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<PolicyChoicesModel**>(_a[0]) = std::move(_r); }  break;
        case 7: { PolicyChoicesModel* _r = _t->valuesModelForFilesystemsSection();
            if (_a[0]) *reinterpret_cast<PolicyChoicesModel**>(_a[0]) = std::move(_r); }  break;
        case 8: { PolicyChoicesModel* _r = _t->valuesModelForBusSections();
            if (_a[0]) *reinterpret_cast<PolicyChoicesModel**>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->sectionHeaderForSectionType((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->sectionAddButtonToolTipTextForSectionType((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->permissionExists((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->isFilesystemNameValid((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->isDBusServiceNameValid((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->isEnvironmentVariableNameValid((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FlatpakPermissionModel::*)()>(_a, &FlatpakPermissionModel::referenceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FlatpakPermissionModel::*)()>(_a, &FlatpakPermissionModel::showAdvancedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FlatpakPermissionModel::*)()>(_a, &FlatpakPermissionModel::settingsChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< FlatpakReference* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<FlatpakReference**>(_v) = _t->reference(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->showAdvanced(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isDefaults(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isSaveNeeded(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setReference(*reinterpret_cast<FlatpakReference**>(_v)); break;
        case 1: _t->setShowAdvanced(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *FlatpakPermissionModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FlatpakPermissionModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22FlatpakPermissionModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int FlatpakPermissionModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void FlatpakPermissionModel::referenceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void FlatpakPermissionModel::showAdvancedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void FlatpakPermissionModel::settingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
